@@ -4,11 +4,17 @@
 
 import logging
 import os
+import re
 import time
 
 from gremlinapi.alfi import GremlinALFI as alfi
 from gremlinapi.apikeys import GremlinAPIapikeys as apikeys
-from gremlinapi.attack_helpers import *
+from gremlinapi.attack_helpers import (
+    GremlinAttackHelper, GremlinAttackTargetHelper, GremlinTargetHosts, GremlinTargetContainers,
+    GremlinAttackCommandHelper, GremlinResourceAttackHelper, GremlinStateAttackHelper, GremlinNetworkAttackHelper,
+    GremlinCPUAttack, GremlinMemoryAttack, GremlinDiskSpaceAttack, GremlinDiskIOAttack,
+    GremlinShutdownAttack, GremlinProcessKillerAttack, GremlinTimeTravelAttack,
+    GremlinBlackholeAttack, GremlinDNSAttack, GremlinLatencyAttack, GremlinPacketLossAttack)
 from gremlinapi.attacks import GremlinAPIAttacks as Attacks
 from gremlinapi.clients import GremlinAPIClients as Clients
 from gremlinapi.companies import GremlinAPICompanies as Companies
@@ -27,7 +33,11 @@ from gremlinapi.metrics import GremlinAPIMetrics as Metrics
 from gremlinapi.orgs import GremlinAPIOrgs as Orgs
 from gremlinapi.providers import GremlinAPIProviders as Providers
 from gremlinapi.reports import GremlinAPIReports as Reports, GremlinAPIReportsSecurity as SecurityReports
-from gremlinapi.scenario_helpers import *
+from gremlinapi.scenario_helpers import (GremlinScenarioHelper, GremlinScenarioStep, GremlinILFIStep)
+from gremlinapi.scenario_graph_helpers import (GremlinScenarioGraphHelper, GremlinScenarioNode,
+                                               GremlinScenarioAttackNode, GremlinScenarioILFINode,
+                                               GremlinScenarioALFINode, GremlinScenarioDelayNode,
+                                               GremlinScenarioStatusCheckNode)
 from gremlinapi.scenarios import (GremlinAPIScenarios as Scenarios,
                                   GremlinAPIScenariosRecommended as RecommendedScenarios)
 from gremlinapi.schedules import GremlinAPISchedules as Schedules
@@ -46,16 +56,16 @@ class SecretsFilter(logging.Filter):
     def filter(self, record):
         secret_length = 5
         if len(GremlinAPIConfig.api_key) >= secret_length:
-            record.msg = re.sub(rf"\s{GremlinAPIConfig.api_key}[\'\s]?",
-                                ' ...'+GremlinAPIConfig.api_key[-4:],
+            record.msg = re.sub(rf"{GremlinAPIConfig.api_key}[\'\s]?",
+                                '...'+GremlinAPIConfig.api_key[-4:],
                                 record.msg)
         if len(GremlinAPIConfig.bearer_token) >= secret_length:
-            record.msg = re.sub(rf"\s{GremlinAPIConfig.bearer_token}[\'\s]?",
-                                ' ...'+GremlinAPIConfig.bearer_token[-4:],
+            record.msg = re.sub(rf"{GremlinAPIConfig.bearer_token}[\'\s]?",
+                                '...'+GremlinAPIConfig.bearer_token[-4:],
                                 record.msg)
         if len(GremlinAPIConfig.password) >= secret_length:
-            record.msg = re.sub(rf"\s{GremlinAPIConfig.password}[\'\s]?",
-                                ' [PASSWORD REDACTED]',
+            record.msg = re.sub(rf"{GremlinAPIConfig.password}[\'\s]?",
+                                '[PASSWORD REDACTED]',
                                 record.msg)
         return record
 
@@ -105,12 +115,26 @@ GremlinAPIConfig.max_bearer_interval = _max_bearer_interval
 GremlinAPIConfig.http_proxy = _http_proxy
 GremlinAPIConfig.https_proxy = _https_proxy
 
+
 def _response_to_bearer(auth_response):
-    log.debug(auth_response[0]['header'])
+    # log.debug(auth_response[0]['header'])
     return auth_response[0]['header']
 
+
 def login(email=GremlinAPIConfig.user, password=GremlinAPIConfig.password,
           company_name=GremlinAPIConfig.company_name, token=GremlinAPIConfig.user_mfa_token_value):
+    if GremlinAPIConfig.user != email:
+        log.debug('Received user without value being present in config, updating config to match.')
+        GremlinAPIConfig.user = email
+    if GremlinAPIConfig.password != password:
+        log.debug('Received password without value being present in config, updating config to match.')
+        GremlinAPIConfig.password = password
+    if GremlinAPIConfig.company_name != company_name:
+        log.debug('Received company name without value being present in config, updating config to match.')
+        GremlinAPIConfig.company_name = company_name
+    if token and GremlinAPIConfig.user_mfa_token_value != token:
+        log.debug('Received mfa token without value being present in config, updating config to match.')
+        GremlinAPIConfig.user_mfa_token_value = token
     if(not _bearer_token_timestamp
        or not _api_bearer_token
        or (time.monotonic() - GremlinAPIConfig.bearer_timestamp >= GremlinAPIConfig.max_bearer_interval)):
@@ -121,7 +145,7 @@ def login(email=GremlinAPIConfig.user, password=GremlinAPIConfig.password,
         else:
             log.debug(f'Non-MFA Login for {email} in company {company_name}')
             auth_response = userAuth.auth_user(email=email, password=password, companyName=company_name)
-        log.debug(auth_response)
+        # log.debug(auth_response)
         GremlinAPIConfig.bearer_token = _response_to_bearer(auth_response)
         GremlinAPIConfig.bearer_timestamp = time.monotonic()
     else:
